@@ -1027,6 +1027,8 @@ all_zombie = {
 zombie_price = [50, 75, 75, 125, 100, 175, 150, 300, 50]
 
 # 初始化命令----------------------------------------------------------------------------
+
+pvz_signin = on_command("pvz签到", block=True, priority=5, aliases={"植物大战僵尸签到"})
 look_bag = on_command("查看背包", block=True, priority=5, aliases={"我的背包"})
 look_lawn = on_command("查看草坪", block=True, priority=5, aliases={"我的草坪"})
 look_shop = on_command("查看商店", block=True, priority=5)
@@ -1039,6 +1041,24 @@ play_with_computer_plant = on_command(
 _help = on_command("植物大战僵尸帮助", aliases={"pvz帮助"}, priority=5, block=True)
 fight = on_command("入侵", priority=5, block=True)
 
+# pvz签到-----------------------------------------------------------------------------
+
+
+@pvz_signin.handle()
+async def _(bot: Bot, event: MessageEvent, state: T_State):
+    flag, users = read_data(Path(bag_path))
+    users_id = [x[0] for x in users]
+    user_id = str(event.user_id)
+    if user_id in users_id:
+        users[users_id.index(user_id)][3] = str(
+            int(users[users_id.index(user_id)][3]) + 100)
+        flag = write_data(Path(bag_path), users)
+        msg = "今天获得了50阳光，已经放入您的背包"
+    else:
+        msg = "您暂未注册植物大战僵尸功能，可以通过“查看背包”或“我的背包”来进行注册"
+    await pvz_signin.finish(msg, at_sender=True)
+
+
 # 查看背包-----------------------------------------------------------------------------
 
 
@@ -1081,7 +1101,7 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
         flag = write_data(Path(bag_path), users)
         await asyncio.sleep(1)
         if flag:
-            await look_bag.finish("恭喜您第一次开启背包，自动自动赠送一个豌豆射手和普通僵尸，可以通过签到来获取每天的50阳光哦", at_sender=True)
+            await look_bag.finish("恭喜您第一次开启背包，自动自动赠送一个豌豆射手和普通僵尸，可以通过签到来获取每天的100阳光哦", at_sender=True)
         else:
             await look_bag.finish("写入文件出错，请联系管理员")
 
@@ -1589,7 +1609,9 @@ async def _(bot: Bot, event: MessageEvent, state: T_State):
           "**************************************************\n" \
           "通过'入侵'来操纵你的僵尸摧毁他人的防御\n例如'入侵 @龙城孤笑'\n" \
           "**************************************************\n" \
-          "总之，在植物大战僵尸的世界中，祝你玩得开心，享受这个过程！\n\nCreate by longchengguxiao"
+          "总之，在植物大战僵尸的世界中，祝你玩得开心，享受这个过程！\n\n" \
+          "插件中所有数据以及图片来源于 ’植物大战僵尸吧‘ 提供的全图鉴中v3.6.0，在此由衷感谢数据支持。\n\n" \
+          "Create by longchengguxiao"
     await asyncio.sleep(1)
     draw_test(res, (255, 255, 153), Path(
         PVZ_OUTPUT_PATH, "help.png"), Path(FONT_PATH))
@@ -1628,4 +1650,4 @@ def read_data(path: Path) -> (bool, list):
         return STATE_OK, infos
     except BaseException as e:
         print(e)
-        return STATE_ERROR, []
\ No newline at end of file
+        return STATE_ERROR, []
